/**
 * A number value argument to a Task
 *
 * Either obtained from the current state, or from a literal number.
 *
 * This class is only necessary until https://github.com/awslabs/aws-cdk/issues/1455 is solved,
 * after which time we'll be able to use actual numbers to encode Tokens.
 */
export declare class NumberValue {
    private readonly n?;
    private readonly path?;
    /**
     * Use a literal number
     */
    static fromNumber(n: number): NumberValue;
    /**
     * Obtain a number from the current state
     */
    static fromJsonPath(path: string): NumberValue;
    private constructor();
    /**
     * Return whether the NumberValue contains a literal number
     */
    readonly isLiteralNumber: boolean;
    /**
     * Get the literal number from the NumberValue
     */
    readonly numberValue: number;
    /**
     * Get the JSON Path from the NumberValue
     */
    readonly jsonPath: string;
}
