import sns = require('@aws-cdk/aws-sns');
import sfn = require('@aws-cdk/aws-stepfunctions');
/**
 * Properties for PublishTask
 */
export interface PublishToTopicProps {
    /**
     * The text message to send to the queue.
     *
     * Exactly one of `message` and `messageObject` is required.
     */
    readonly message?: string;
    /**
     * Object to be JSON-encoded and used as message
     *
     * Exactly one of `message`, `messageObject` and `messagePath` is required.
     */
    readonly messageObject?: string;
    /**
     * If true, send a different message to every subscription type
     *
     * If this is set to true, message must be a JSON object with a
     * "default" key and a key for every subscription type (such as "sqs",
     * "email", etc.) The values are strings representing the messages
     * being sent to every subscription type.
     *
     * @see https://docs.aws.amazon.com/sns/latest/api/API_Publish.html#API_Publish_RequestParameters
     */
    readonly messagePerSubscriptionType?: boolean;
    /**
     * Message subject
     */
    readonly subject?: string;
}
/**
 * A StepFunctions Task to invoke a Lambda function.
 *
 * A Function can be used directly as a Resource, but this class mirrors
 * integration with other AWS services via a specific class instance.
 */
export declare class PublishToTopic implements sfn.IStepFunctionsTask {
    private readonly topic;
    private readonly props;
    constructor(topic: sns.ITopic, props: PublishToTopicProps);
    bind(task: sfn.Task): sfn.StepFunctionsTaskProperties;
}
