import ec2 = require('@aws-cdk/aws-ec2');
import ecs = require('@aws-cdk/aws-ecs');
import sfn = require('@aws-cdk/aws-stepfunctions');
import { ContainerOverride } from './run-ecs-task-base-types';
/**
 * Basic properties for ECS Tasks
 */
export interface CommonEcsRunTaskProps {
    /**
     * The topic to run the task on
     */
    readonly cluster: ecs.ICluster;
    /**
     * Task Definition used for running tasks in the service
     */
    readonly taskDefinition: ecs.TaskDefinition;
    /**
     * Container setting overrides
     *
     * Key is the name of the container to override, value is the
     * values you want to override.
     */
    readonly containerOverrides?: ContainerOverride[];
    /**
     * Whether to wait for the task to complete and return the response
     *
     * @default true
     */
    readonly synchronous?: boolean;
}
/**
 * Construction properties for the BaseRunTaskProps
 */
export interface EcsRunTaskBaseProps extends CommonEcsRunTaskProps {
    /**
     * Additional parameters to pass to the base task
     */
    readonly parameters?: {
        [key: string]: any;
    };
}
/**
 * A StepFunctions Task to run a Task on ECS or Fargate
 */
export declare class EcsRunTaskBase implements ec2.IConnectable, sfn.IStepFunctionsTask {
    private readonly props;
    /**
     * Manage allowed network traffic for this service
     */
    readonly connections: ec2.Connections;
    private securityGroup?;
    private networkConfiguration?;
    private readonly sync;
    constructor(props: EcsRunTaskBaseProps);
    bind(task: sfn.Task): sfn.StepFunctionsTaskProperties;
    protected configureAwsVpcNetworking(vpc: ec2.IVpcNetwork, assignPublicIp?: boolean, subnetSelection?: ec2.SubnetSelection, securityGroup?: ec2.ISecurityGroup): void;
    private makePolicyStatements;
    private taskExecutionRoles;
}
